@@ -38,6 +38,7 @@ QMap<QString, QDateTime> QgsOracleConn::sBrokenConnections;
 QgsOracleConn *QgsOracleConn::connectDb( const QgsDataSourceUri &uri, bool transaction )
 {
   const QString conninfo = toPoolName( uri );
+  QgsDebugMsgLevel( QStringLiteral( "Trying to connect to %1 (in transaction: %2)" ).arg( conninfo ).arg( transaction ? QStringLiteral( "YES" ) : QStringLiteral( "NO" ) ), 2 );
   const QPair<QString, QThread *> connInfoThread( conninfo, QThread::currentThread() );
 
   if ( !transaction )
@@ -50,23 +51,26 @@ QgsOracleConn *QgsOracleConn::connectDb( const QgsDataSourceUri &uri, bool trans
     }
   }
 
+  QgsDebugMsgLevel( QStringLiteral( "Making new connection" ), 2 );
   QgsOracleConn *conn = new QgsOracleConn( uri, transaction );
 
   if ( conn->mRef == 0 )
   {
+    QgsDebugMsgLevel( QStringLiteral( "Connection has no references, deleting..." ), 2 );
     delete conn;
     return nullptr;
   }
 
   if ( !transaction )
   {
+    QgsDebugMsgLevel( QStringLiteral( "Storing connection for this thread" ), 2 );
     sConnections.insert( connInfoThread, conn );
   }
 
   return conn;
 }
 
-QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
+QgsOracleConn::QgsOracleConn( const QgsDataSourceUri &uri, bool transaction )
   : mRef( 1 )
   , mCurrentUser( QString() )
   , mHasSpatial( -1 )
@@ -76,25 +80,26 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
 
   // will be used for logging and access connection from connection pool by name,
   // so we don't want login/password here
-  mConnInfo = uri.connectionInfo( false );
+  mConnInfo = toPoolName( uri );
 
-  uri = QgsDataSourceUri( uri.connectionInfo( true ) );
+  QgsDataSourceUri expandedUri = QgsDataSourceUri( uri.connectionInfo( true ) );
 
-  QString database = databaseName( uri.database(), uri.host(), uri.port() );
+  QString database = databaseName( expandedUri.database(), expandedUri.host(), expandedUri.port() );
   QgsDebugMsgLevel( QStringLiteral( "New Oracle database " ) + database, 2 );
 
   mDatabase = QSqlDatabase::addDatabase( QStringLiteral( "QOCISPATIAL" ), QStringLiteral( "oracle%1" ).arg( snConnections++ ) );
   mDatabase.setDatabaseName( database );
-  QString options = uri.hasParam( QStringLiteral( "dboptions" ) ) ? uri.param( QStringLiteral( "dboptions" ) ) : QStringLiteral( "OCI_ATTR_PREFETCH_ROWS=1000" );
+  QString options = expandedUri.hasParam( QStringLiteral( "dboptions" ) ) ? expandedUri.param( QStringLiteral( "dboptions" ) ) : QStringLiteral( "OCI_ATTR_PREFETCH_ROWS=1000" );
   if ( mTransaction )
     options += ( !options.isEmpty() ? QStringLiteral( ";" ) : QString() ) + QStringLiteral( "COMMIT_ON_SUCCESS=false" );
-  QString workspace = uri.hasParam( QStringLiteral( "dbworkspace" ) ) ? uri.param( QStringLiteral( "dbworkspace" ) ) : QString();
+  const QString workspace = expandedUri.hasParam( QStringLiteral( "dbworkspace" ) ) ? expandedUri.param( QStringLiteral( "dbworkspace" ) ) : QString();
+  QgsDebugMsgLevel( QStringLiteral( "Using workspace %1" ).arg( workspace ), 2 );
   mDatabase.setConnectOptions( options );
-  mDatabase.setUserName( uri.username() );
-  mDatabase.setPassword( uri.password() );
+  mDatabase.setUserName( expandedUri.username() );
+  mDatabase.setPassword( expandedUri.password() );
 
-  QString username = uri.username();
-  QString password = uri.password();
+  QString username = expandedUri.username();
+  QString password = expandedUri.password();
 
   if ( sBrokenConnections.contains( mConnInfo ) )
   {
@@ -130,11 +135,11 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
 
       if ( !username.isEmpty() )
       {
-        uri.setUsername( username );
+        expandedUri.setUsername( username );
       }
 
       if ( !password.isEmpty() )
-        uri.setPassword( password );
+        expandedUri.setPassword( password );
 
       QgsDebugMsgLevel( "Connecting to " + database, 2 );
       mDatabase.setUserName( username );
