@@ -174,6 +174,8 @@ class QgsWmsProvider final : public QgsRasterDataProvider
     static QString WMS_KEY;
     static QString WMS_DESCRIPTION;
 
+    static inline QString DEFAULT_LATLON_CRS = QStringLiteral( "CRS:84" );
+
     /**
      * Constructor for the provider.
      *
@@ -282,12 +284,12 @@ class QgsWmsProvider final : public QgsRasterDataProvider
       mProviderResamplingEnabled = enable;
       return true;
     }
-    bool setZoomedInResamplingMethod( ResamplingMethod method ) override
+    bool setZoomedInResamplingMethod( Qgis::RasterResamplingMethod method ) override
     {
       mZoomedInResamplingMethod = method;
       return true;
     }
-    bool setZoomedOutResamplingMethod( ResamplingMethod method ) override
+    bool setZoomedOutResamplingMethod( Qgis::RasterResamplingMethod method ) override
     {
       mZoomedOutResamplingMethod = method;
       return true;
