@@ -107,11 +107,10 @@ void TestQgsProject::cleanupTestCase()
 
 void TestQgsProject::testDirtySet()
 {
-  QgsProject p;
-  bool dirtySet = false;
-  connect( &p, &QgsProject::dirtySet, [&] { dirtySet = true; } );
-  p.setDirty( true );
-  QVERIFY( dirtySet );
+  QgsProject project;
+  QSignalSpy dirtySetSpy( &project, &QgsProject::dirtySet );
+  project.setDirty( true );
+  QVERIFY( dirtySetSpy.count() == 1 );
 }
 
 void TestQgsProject::testReadPath()
